pub trait FreedomTime {
// Required method
fn freedomstamp(&self) -> u64;
}Expand description
FreedomTime is aware of the Birthday of Freedom (July 4, ’76).
Required Methods
Sourcefn freedomstamp(&self) -> u64
fn freedomstamp(&self) -> u64
Number of whole seconds since the Birthday of Freedom.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".